SystemOp

Enum SystemOp 

#[non_exhaustive]
pub enum SystemOp<C>
where C: ChannelKind,
{
Show 13 variants Auth { client_id: Uuid, token: Option<String>, capabilities: Vec<C>, resume_cursor: Option<u64>, resume_cursors: HashMap<C, u64>, }, AuthOk { resume_cursor: u64, resume_cursors: HashMap<C, u64>, }, Error { message: String, }, Ping, Pong, Slow { window: Option<u32>, }, Ack { channel: C, cursor: u64, }, ResumeRequired { channel: C, from_cursor: u64, }, Subscribe { channels: Vec<C>, }, Unsubscribe { channels: Vec<C>, }, Health { status: String, detail: Option<String>, }, Features { supported: Vec<String>, requested: Vec<String>, }, Goodbye { reason: Option<String>, },
}
System control plane messages that travel on the system channel.

Parameterized by C: ChannelKind so that channel references in Auth, Ack, Subscribe, etc. use the caller’s channel type.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Auth

Fields

client_id: Uuid
capabilities: Vec<C>
resume_cursor: Option<u64>
resume_cursors: HashMap<C, u64>


AuthOk

Fields

resume_cursor: u64
resume_cursors: HashMap<C, u64>


Error

Fields

message: String


Ping



Pong



Slow

Fields

window: Option<u32>


Ack

Fields

channel: C
cursor: u64


ResumeRequired

Fields

channel: C
from_cursor: u64


Subscribe

Fields

channels: Vec<C>


Unsubscribe

Fields

channels: Vec<C>


Health

Fields

status: String
detail: Option<String>


Features

Fields

supported: Vec<String>
requested: Vec<String>


Goodbye

Fields

reason: Option<String>

Implementations

Source

impl<C> SystemOp<C>
where C: ChannelKind,

pub fn auth_ok(resume_cursor: u64) -> SystemOp<C>