pub fn compute_delta(
base_cursor: u64,
current: &str,
next: &str,
) -> PayloadDeltaExpand description
Compute a naive delta that replaces the tree when the content differs.
pub fn compute_delta(
base_cursor: u64,
current: &str,
next: &str,
) -> PayloadDeltaCompute a naive delta that replaces the tree when the content differs.