pub struct RelayController { /* private fields */ }Expand description
Performs server-side relay with bandwidth accounting and rate limiting.
Implementations
Sourceimpl RelayController
impl RelayController
pub fn new(limits: RelayBandwidth) -> Self
Sourcepub fn relay<D: TransportDispatcher>(
&self,
from: Uuid,
to: Uuid,
packet: TransportPacket,
dispatcher: &D,
) -> Result<RelayOutcome, TransportError>
pub fn relay<D: TransportDispatcher>( &self, from: Uuid, to: Uuid, packet: TransportPacket, dispatcher: &D, ) -> Result<RelayOutcome, TransportError>
Relay a packet from one peer to another with rate limiting applied to the sender.
Sourcepub fn total_bytes(&self, peer: Uuid) -> u64
pub fn total_bytes(&self, peer: Uuid) -> u64
Returns the total number of bytes relayed for a peer (sender-scoped).